@@ -1634,9 +1634,10 @@ class Update(MethodsInterface):
         # < 0  binhost level low
         # == 0 binhost level adequate
         # > 0  binhost level high
-        if level is None:
+        local_lvl = self.clVars.Get("update.cl_update_level")
+        if level is None or local_lvl == "":
             return None
-        return level - int(self.clVars.Get("update.cl_update_level"))
+        return level - int(local_lvl)
 
     def is_branch_set(self):
         #basically, if any of the branches are specified, we won't use migration
